@@ -152,7 +152,9 @@ else:
             except Exception as ex:
                 logger.error("Receive exception", exc_info=True)
 
-        def send(self, message_id, message, extended=False):
+        def send(self, message_id, message, extended=False, canfd=False):
+            if canfd:
+                raise DriverError('CANFD not supported by PythonCAN')
             self._check_write_feedback()
             try:
                 self._write_queue.put_nowait(CANFrame(message_id, message, extended))
