@@ -225,6 +225,7 @@ class TransferHookDispatcher(object):
 class Node(Scheduler):
     def __init__(self, can_driver, node_id=None, node_status_interval=None,
                  mode=None, node_info=None, catch_handler_exceptions=True,
+                 send_canfd=False,
                  **_extras):
         """
         It is recommended to use make_node() rather than instantiating this type directly.
@@ -250,6 +251,7 @@ class Node(Scheduler):
 
         self._can_driver = can_driver
         self._node_id = node_id
+        self._send_canfd = send_canfd
 
         self._transfer_manager = transport.TransferManager()
         self._outstanding_requests = {}
@@ -277,6 +279,10 @@ class Node(Scheduler):
         self.node_info = node_info or dronecan.uavcan.protocol.GetNodeInfo.Response()     # @UndefinedVariable
         self.add_handler(dronecan.uavcan.protocol.GetNodeInfo, on_get_node_info)          # @UndefinedVariable
 
+    def set_canfd(self, send_canfd):
+        '''change default send of CANFD'''
+        self._send_canfd = send_canfd
+
     @property
     def is_anonymous(self):
         return (self._node_id or 0) == 0
@@ -420,9 +426,12 @@ class Node(Scheduler):
                     break
             self._poll_scheduler_and_get_next_deadline()
 
-    def request(self, payload, dest_node_id, callback, priority=None, timeout=None):
+    def request(self, payload, dest_node_id, callback, priority=None, timeout=None, canfd=None):
         self._throw_if_anonymous()
 
+        if canfd is None:
+            canfd = self._send_canfd
+
         # Preparing the transfer
         transfer_id = self._next_transfer_id((get_dronecan_data_type(payload).default_dtid, dest_node_id))
         transfer = transport.Transfer(payload=payload,
@@ -431,14 +440,15 @@ class Node(Scheduler):
                                       transfer_id=transfer_id,
                                       transfer_priority=priority or DEFAULT_TRANSFER_PRIORITY,
                                       service_not_message=True,
-                                      request_not_response=True)
+                                      request_not_response=True,
+                                      canfd=canfd)
 
         # Calling hooks
         self._transfer_hook_dispatcher.call_hooks(self._transfer_hook_dispatcher.TRANSFER_DIRECTION_OUTGOING, transfer)
 
         # Sending the transfer
         for frame in transfer.to_frames():
-            self._can_driver.send(frame.message_id, frame.bytes, extended=True)
+            self._can_driver.send(frame.message_id, frame.bytes, extended=True, canfd=canfd)
 
         # Registering a callback that will be invoked if there was no response after 'timeout' seconds
         def on_timeout():
@@ -466,9 +476,12 @@ class Node(Scheduler):
 
         logger.debug("Node.request(dest_node_id={0:d}): sent {1!r}".format(dest_node_id, payload))
 
-    def respond(self, payload, dest_node_id, transfer_id, priority):
+    def respond(self, payload, dest_node_id, transfer_id, priority, canfd=None):
         self._throw_if_anonymous()
 
+        if canfd is None:
+            canfd = self._send_canfd
+
         transfer = transport.Transfer(
             payload=payload,
             source_node_id=self._node_id,
@@ -476,31 +489,36 @@ class Node(Scheduler):
             transfer_id=transfer_id,
             transfer_priority=priority,
             service_not_message=True,
-            request_not_response=False
+            request_not_response=False,
+            canfd=canfd
         )
 
         self._transfer_hook_dispatcher.call_hooks(self._transfer_hook_dispatcher.TRANSFER_DIRECTION_OUTGOING, transfer)
 
         for frame in transfer.to_frames():
-            self._can_driver.send(frame.message_id, frame.bytes, extended=True)
+            self._can_driver.send(frame.message_id, frame.bytes, extended=True, canfd=canfd)
 
         logger.debug("Node.respond(dest_node_id={0:d}, transfer_id={0:d}, priority={0:d}): sent {1!r}"
                      .format(dest_node_id, transfer_id, priority, payload))
 
-    def broadcast(self, payload, priority=None):
+    def broadcast(self, payload, priority=None, canfd=None):
         self._throw_if_anonymous()
 
+        if canfd is None:
+            canfd = self._send_canfd
+        
         transfer_id = self._next_transfer_id(get_dronecan_data_type(payload).default_dtid)
         transfer = transport.Transfer(payload=payload,
                                       source_node_id=self._node_id,
                                       transfer_id=transfer_id,
                                       transfer_priority=priority or DEFAULT_TRANSFER_PRIORITY,
-                                      service_not_message=False)
+                                      service_not_message=False,
+                                      canfd=canfd)
 
         self._transfer_hook_dispatcher.call_hooks(self._transfer_hook_dispatcher.TRANSFER_DIRECTION_OUTGOING, transfer)
 
         for frame in transfer.to_frames():
-            self._can_driver.send(frame.message_id, frame.bytes, extended=True)
+            self._can_driver.send(frame.message_id, frame.bytes, extended=True, canfd=canfd)
 
     def close(self):
         self._can_driver.close()
